@@ -17,7 +17,9 @@ class Distro(Module):
         usr = kw['usr']
         pub = kw['pub']
 
-        if not target.User(usr).deploy():
+        distro = target.distro
+
+        if not distro.user(usr).deploy():
             return False
 
         if not target.deploy('sudoers', user=usr):
