@@ -1,4 +1,4 @@
-from .init import Module
+from setux.core.module import Module
 
 
 class Distro(Module):
